import { Component, ViewChild } from '@angular/core';
import { IgxGridComponent, IgxColumnComponent, GridColumnDataType } from '@infragistics/igniteui-angular';
import { Workbook, WorkbookFormat, WorksheetColumnWidthUnit, CellFill, VerticalCellAlignment, HorizontalCellAlignment } from 'igniteui-angular-excel';
import { ExcelUtility } from './excel-utility';
import { employeesData } from './localData';

@Component({
  selector: 'app-root',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.scss']
})
export class AppComponent {
  @ViewChild('grid', { static: true }) public grid: IgxGridComponent | undefined;
  public localData: any[] = [];

  public columns: { dataType: GridColumnDataType, field: string }[] = [
    { dataType: GridColumnDataType.String, field: 'EmployeeID' },
    { dataType: GridColumnDataType.String, field: 'FirstName'},
    { dataType: GridColumnDataType.String, field: 'Country'}
  ];
  
  title = 'Grid';
  constructor() { }

  ngOnInit() {
    this.localData = employeesData;
  }

  public exportButtonHandler() {
    const workbook = new Workbook(WorkbookFormat.Excel2007);
    const worksheet = workbook.worksheets().add('First Sheet');

    worksheet.setDefaultColumnWidth(250, WorksheetColumnWidthUnit.Pixel);
    worksheet.defaultRowHeight = 370;
   

    this.grid?.columnList.forEach((col: IgxColumnComponent, index) => {
      worksheet.rows(0).cells(index).value = col.field;
    });
    worksheet.rows(0).cellFormat.rotation = 90;
    worksheet.rows(0).cellFormat.alignment = HorizontalCellAlignment.Center;
    worksheet.rows(0).height = 2000;

    for (let i = 0; i < this.localData.length; i++) {
      let counter = 0;
      for (let cell in this.localData[i]) {
        worksheet.rows(i + 1).setCellValue(counter, this.localData[i][cell]);
        counter++;
      }
    }    

    ExcelUtility.save(workbook, 'fileName');
  }
}
