import { saveAs } from "file-saver"; // npm package: "file-saver": "^1.3.8"
import { Workbook } from 'igniteui-angular-excel';
import { WorkbookFormat } from 'igniteui-angular-excel';
import { WorkbookSaveOptions } from 'igniteui-angular-excel';

export class ExcelUtility {
  public static getExtension(format: WorkbookFormat) {
    switch (format) {
      case WorkbookFormat.StrictOpenXml:
      case WorkbookFormat.Excel2007:
        return ".xlsx";
      case WorkbookFormat.Excel2007MacroEnabled:
        return ".xlsm";
      case WorkbookFormat.Excel2007MacroEnabledTemplate:
        return ".xltm";
      case WorkbookFormat.Excel2007Template:
        return ".xltx";
      case WorkbookFormat.Excel97To2003:
        return ".xls";
      case WorkbookFormat.Excel97To2003Template:
        return ".xlt";
    }
  }

  public static save(workbook: Workbook, fileNameWithoutExtension: string): Promise<string> {
    return new Promise<string>((resolve, reject) => {
      const opt = new WorkbookSaveOptions();
      opt.type = "blob";

      workbook.save(opt, (d) => {
        const fileExt = ExcelUtility.getExtension(workbook.currentFormat);
        const fileName = fileNameWithoutExtension + fileExt;
        saveAs(d as Blob, fileName);
        resolve(fileName);
      }, (e) => {
        reject(e);
      });
    });
  }

  private static readFileAsUint8Array(file: File): Promise<Uint8Array> {
    return new Promise<Uint8Array>((resolve, reject) => {
      const fr = new FileReader();
      fr.onerror = (e) => {
        reject(fr.error);
      };

      if (fr.readAsBinaryString) {
        fr.onload = (e) => {
          const rs = (fr as any).resultString;
          const str: string = rs != null ? rs : fr.result;
          const result = new Uint8Array(str.length);
          for (let i = 0; i < str.length; i++) {
            result[i] = str.charCodeAt(i);
          }
          resolve(result);
        };
        fr.readAsBinaryString(file);
      } else {
        fr.onload = (e) => {
          resolve(new Uint8Array(fr.result as ArrayBuffer));
        };
        fr.readAsArrayBuffer(file);
      }
    });
  }
}
